/*************************************************************
	File:		FTDI_IO.h
	Project:	USB PTP\MTP Camera Controller

	Author:				Luke Skaff
	Author's Email:	Luke.Skaff@gmail.com
	Author's Website:	http://blog.LukeSkaff.com/
							http://www.LukeSkaff.com/
 ************************************************************/

#ifndef FTDI_IO_H
#define FTDI_IO_H

	#include "globals.h"
	#include "hardware.h"
	#include "delay.h"

	/* AVR Dependent Libraries */
	#ifdef USE_PLATFORM_AVR
		#include <avr/io.h>
		#include <stdio.h>
	#endif

	/* Nintendo DS Dependent Libraries */
	#ifdef USE_PLATFORM_NDS
		#include <PA9.h>
	#endif


	/******************
	 Timeouts & Delays
	 ******************/
	#define TIMEOUT_DEFAULT      		16U   /* 16ms */
	#define TIMEOUT_LONG         		1600U	/* 1600ms */
	#define TIMEOUT_LONG2x       		3200U	/* 3200ms */

	#define DELAY_USB_NAK      		160U	/* 160ms */
	#define USB_NAK_RETRY_CNT  		0x05	/* If USB responds with NAK, try to read this many times*/
	#define USB_WRITE_TO_READ_DELAY	16U	/* 16 ms */


	/* FTDI Command values */
	extern volatile unsigned char out_IPH[4];
	extern volatile unsigned char out_SCS[4];
	extern volatile unsigned char out_DSD[4];

	extern volatile unsigned char debugIOenable;
	extern volatile unsigned char debugIOenableASCII;

	/*** Function prototypes ***/
	unsigned char FTDI_TX_Byte_NoWait(unsigned char);
	unsigned char FTDI_RX_Byte_NoWait(volatile unsigned char *);
	unsigned char FTDI_TX_Byte(unsigned char, unsigned int);
	unsigned char FTDI_RX_Byte(volatile unsigned char *, unsigned int);
	unsigned char FTDI_TX_4B(volatile unsigned char [4], unsigned char,unsigned int);
	unsigned char FTDI_Dummy_RD_Timeout(unsigned int);
	unsigned char FTDI_init(void);
	unsigned char FTDI_DRD(volatile unsigned char *);
	unsigned char FTDI_3E0D_Check(void);
	unsigned char USB_RX_Byte(volatile unsigned char *);
	void USB_RX_Byte_Reset(void);
	unsigned char USB_RX_Byte_StartSession(volatile uint32_t *);


#endif  /* End of define FTDI_IO_H */
