/*************************************************************
 File:		PTP_basic.h
 Project:	USB PTP\MTP Camera Controller

 Author:					Luke Skaff
 Author's Email:		Luke.Skaff@gmail.com
 Author's Website:	http://blog.LukeSkaff.com/
							http://www.LukeSkaff.com/
 ************************************************************/


#ifndef PTP_BASIC_H
#define PTP_BASIC_H

	#include "globals.h"
	#include "FTDI_IO.h"
	#include "delay.h"

	/* AVR Dependent Libraries */
	#ifdef USE_PLATFORM_AVR
		#include <avr/pgmspace.h> /* Used for AVR lookup table */
	#endif



	/* Global Variables */
	extern unsigned char debugWaitForEventAllIO;



	/* 
	PTP/MTP values where obtained from packet sniffing USB traffic then cross referencing these
	values to the Gphoto ptp.h file. http://www.gphoto.org/
	*/

	/* PTP Types */
	#define PTP_CONTAINER_CMD        0x0001
	#define PTP_CONTAINER_DATA       0x0002
	#define PTP_CONTAINER_RESPONCE   0x0003
	#define PTP_CONTAINER_EVENT      0x0004

	/* PTP Operation Codes */
	#define PTP_OC_OpenSession			0x1002
	#define PTP_OC_CloseSession		0x1003

	/* MTP Operation Codes */
	#define CANON_SetDevicePropValueEx				0x9110
	#define CANON_SetRemoteMode						0x9114

	#define PTP_OC_CANON_SetRemoteMode				0x9114
	#define PTP_OC_CANON_SetRemoteMode_CLEAR		0x0000
	#define PTP_OC_CANON_SetRemoteMode_SET			0x0001

	#define PTP_OC_CANON_EOS_SetEventMode			0x9115
	#define PTP_OC_CANON_EOS_SetEventMode_CLEAR	0x0000
	#define PTP_OC_CANON_EOS_SetEventMode_SET		0x0001

	#define CANON_RemoteRelease						0x910F
	#define CANON_GetEvent								0x9116

	/* Canon EOS events */
	#define PTP_EC_CANON_EOS_ObjectAddedEx					0xc181
	#define PTP_EC_CANON_EOS_RequestObjectTransfer		0xc186
	#define PTP_EC_CANON_EOS_PropValueChanged				0xc189




	/* PTP Delays */
	#define PTP_CANON_WaitForEvent_DELAY	16U /* 16 ms */

	/*** Function prototypes ***/
	unsigned char PTP_Container_TX(void);
	unsigned char PTP_Container_RX(void);
	unsigned char PTP_OpenSession(void);
	unsigned char PTP_CloseSession(void);
	unsigned char PTP_CANON_SetRemoteMode(void);
	unsigned char PTP_CANON_SendOpCode(uint16_t,uint16_t);
	unsigned char PTP_CANON_WaitForEvent(uint16_t);
	unsigned char PTP_CANON_SetExposure(unsigned char);
	unsigned char PTP_CANON_TakePicture();
	unsigned char PTP_CANON_BraketSeq_Man(unsigned char,unsigned char);

#endif  /* End of define PTP_BASIC */
