/*************************************************************
	File:		globals.h
	Project:	USB PTP\MTP Camera Controller

	Author:				Luke Skaff
	Author's Email:	Luke.Skaff@gmail.com
	Author's Website:	http://blog.LukeSkaff.com/
							http://www.LukeSkaff.com/
 ************************************************************/

#ifndef GLOBALS_H
#define GLOBALS_H

	/* 8-bit bool equiv */
	#define	TRUE_B	0xFF
	#define	FALSE_B	0x00

	/**** Error Codes ****/
	#define ECODE_NO_ERROR				0x00

	/*	FTDI timeout occurs when a function is trying to read or write to the FTDI
		chip but is unable to due to the read or write ready line not being set.
		This can happen if to short of a timeout is specified so the FTDI does not have 
		enough time to ready data or is the FTDI chip has hung (which does happen ugh!)
		Reset is recommend when this happens */
	#define ECODE_FTDI_TIMEDOUT		0x01
	#define ECODE_FTDI_TX_TIMEDOUT	0x02
	#define ECODE_FTDI_RX_TIMEDOUT	0x03

	/*	Read count maxed out in dummy read function, FTDI disconnected or TXE_ pin staying low
		which causes the code to reads from the FTDI non-stop. A counter is set for each read and if it
		exceeded a specified value this error is returned*/
	#define ECODE_FTDI_READ_MAXED		0x10

	/*	USB timeout, used in FTDI_DRD function.  If FTDI returns a 0x000D to a FTDI DRD command
		function retries until USB_NAK_RETRY_CNT is reached.
		1) Timed out while waiting for USB response
		2) There is no new data to read from USB device, USB device returned a NAK */
	#define ECODE_FTDI_USB_TIMEDOUT	0x20

	/* 0x3E0D not received from FTDI, used in FTDI_3E0D_Check function*/
	#define ECODE_FTDI_NO_3E0D			0x30

	/* Return if USB read is done (no error) or if a session was never opened */
	#define ECODE_USB_RX_BYTE_SESSION_CLOSED			0x40

	/* Return if a USB read session is already open and the previous read is not finished */
	#define ECODE_USB_RX_BYTE_SESSION_IN_PROGRESS	0x41



	/********************* Debug *********************/
	/*** Comment out unwanted debugging functions ***/

	/* Debug functions are used to send all FTDI RX and TX bytes and/or error(s) to terminal */
	#include "terminal.h"

	/* Output error messages and codes to terminal */
	#define DEBUGoutput
	
	/* Send every byte RX and TX from FTDI to terminal in HEX */
	//#define DEBUG_IO_OUTPUT

	/* Send bytes RX and TX from FTDI to terminal when enabled selectively in code.
	   Set global variable debugIOenable to 0xFF to send FTDI IO out to terminal */
	//#define DEBUG_IO_OUTPUT_SELECTIVE
	//#define DEBUG_IO_OUTPUT_SELECTIVE_ASCII

	/* Send out data recieved from USB to terminal, will not sent out FTDI commands, just USB data
		- DEBUG_IO_OUTPUT_SELECTIVE_ASCII must be defined \ uncommented for this to work */
	//#define DEBUG_IO_OUTPUT_USB_RX_ASCII

	/* Output each event code processed in function PTP_CANON_WaitForEvent out to terminal in ASCII */
	//#define DEBUG_TX_EVENT_CODES

	/* Output all traffic to and from the FTDI chip in the PTP_CANON_WaitForEvent out to terminal in ASCII
		if the global variable debugWaitForEventAllIO is set to 0xFF 
		- DEBUG_IO_OUTPUT_SELECTIVE_ASCII must be defined \ uncommented for this to work */
	//#define DEBUG_WaitForEvent_ALL_TRAFFIC_OUT_SELECTIVE


	/* Do NOT comment out below */
	/* ------------------------ */
	#ifdef DEBUGoutput
		#define DEBUG_DETAILED_OUTPUT_W_IF(file,function,ASCIIchar,errorcode) \
			{if(errorCode != ECODE_NO_ERROR) {Debug_Detailed(file,function,ASCIIchar,errorCode);}}
	#else
		#define DEBUG_DETAILED_OUTPUT_W_IF(file,function,ASCIIchar,errorcode) {}
	#endif
	/* ------------------------ */


#endif  /* End of define GLOBALS_H */
