/*************************************************************
	File:		hardware.h
	Project:	USB PTP\MTP Camera Controller

	Author:				Luke Skaff
	Author's Email:	Luke.Skaff@gmail.com
	Author's Website:	http://blog.LukeSkaff.com/
							http://www.LukeSkaff.com/
	
	Comments:	This code is designed to compile for use on an AVR & Nintendo DS
					You must select which platform is being used below
 ************************************************************/

#ifndef HARDWARE_H
#define HARDWARE_H

	/* Select which hardware platform the code is being compiled for */
	/* Do NOT uncomment both platforms */
	#define	USE_PLATFORM_AVR	/* Used for all AVR chips */
	//#define	USE_PLATFORM_NDS	/* Used for compiling on Nintendo DS */


	/* ************  AVR Specific Code ************ */
	#ifdef USE_PLATFORM_AVR
		#define	USE_AVR_MEGA		/* Used for ATMega Chips */
		//#define	USE_AVR_XMEGA	/* Used for ATxMega Chips */

		/**** Global Macros ****/
		#ifdef USE_AVR_MEGA /* Set to use in hardware.h */
			#define bit_Set(port,bit_num) (port = port | (0x01 << bit_num))
			#define bit_Clear(port,bit_num) (port = port & ~(0x01 << bit_num))
		#endif

		#ifdef USE_AVR_XMEGA /* Set to use in hardware.h */
			#define bit_Set(port,bit_num) (port.OUTSET = (0x01 << bit_num))
			#define bit_Clear(port,bit_num) (port.OUTCLR = (0x01 << bit_num))
		#endif

		/* ------ PORT & PIN Definitions ------- */
		#define	FTDI_DATA_PORT			PORTA    //8-BIT FTDI data lines
		#define	FTDI_DATA_PORT_in		PINA     //8-BIT FTDI data lines
		#define	FTDI_IO_CTRL			DDRA
		#define	FTDI_CTRL_PORT			PORTD    //8-BIT FTDI data lines
		#define	FTDI_CTRL_PORT_IN		PIND     //8-BIT FTDI data lines

		#define	FTDI_RXF_				2        //INPUT
		#define	FTDI_TXE_				3        //INPUT
		#define	FTDI_RD_					4        //Output
		#define	FTDI_WR					5        //Output
		#define	FTDI_RESET_				6        //Output
		#define	LA_TRIG					7        //Output

		#define  LEDPORT					PORTC
	#endif /* end USE_PLATFORM_AVR */



	/* ************  Nintendo DS Specific Code ************ */
	#ifdef USE_PLATFORM_NDS

		/**** Macors ****/
		#define bit_Set(data,bit_mask) (data = data | bit_mask)
		#define bit_Clear(data,bit_mask) (data = data & ~bit_mask)
		#define bit_is_set(data, bit_mask) (data & bit_mask)
		#define bit_is_clear(data, bit_mask) (!(data & bit_mask))

		/*
		*******************
		Status Register 0
		*******************
		0x00 - CPLD address
		0x8000000 - Nintendo DS DMA address
		Bit  R\W  Name
		MSB
		7     R
		6     R
		5     R
		4     R
		3     R
		2     R
		1     R
		0     R
		LSB
		*/




		/*
		*******************
		FTDI Control Register
		*******************
		0x01 - CPLD address
		0x8000002 - Nintendo DS DMA address
		Bit  R\W  Name      Description
		MSB
		7    R\W  Reset     0=Reset (pulls reset pin low), 1=Run   
		6     R   Reserved
		5     R   Reserved
		4     R   TXE_
		3    R\W  WR        Wr Pin: 1=write, also enables data output drivers
		2    R\W  WR_EN     Data line driver control: 1=drives output lines D7-D0 0=idle
		1     R   RXF_       
		0    R\W  RD        Rd pin (inverted in CPLD): 1=Read
		LSB
		*/
		#define FTDI_CTRL_REG (*(vu16*)0x8000002)
		#define FTDI_RESET_	0b0000000010000000 //bit 7 bitmask
		//#define bit6		0b0000000001000000 //bit 6 bitmask
		//#define bit5		0b0000000000100000 //bit 5 bitmask
		#define FTDI_TXE_		0b0000000000010000 //bit 4 bitmask
		#define FTDI_WR		0b0000000000001000 //bit 3 bitmask
		#define FTDI_WR_EN	0b0000000000000100 //bit 2 bitmask
		#define FTDI_RXF_		0b0000000000000010 //bit 1 bitmask
		#define FTDI_RD		0b0000000000000001 //bit 0 bitmask
		/*
		*******************
		FTDI Data Register
		*******************
		0x02 - CPLD address
		0x8000004 - Nintendo DS DMA address
		Bit  R\W  Name      Description
		MSB
		7     W   D7
		6     W   D6
		5     W   D5
		4     W   D4
		3     W   D3    
		2     W   D2   
		1     W   D1       
		0     W   D0     
		LSB
		*/
		#define FTDI_DATA_REG (*(vu16*)0x8000004)
		#define FTDI_DEBUG_DATA_REG (*(vu16*)0x8000008)


		/*
		****************************
		FTDI DEBUG Control Register
		****************************
		0x03 - CPLD address
		0x8000006 - Nintendo DS DMA address
		Bit  R\W  Name      Description
		MSB
		7    R\W  Reset     0=Reset (pulls reset pin low), 1=Run   
		6     R   Reserved
		5     R   Reserved
		4     R   TXE_
		3    R\W  WR        Wr Pin: 1=write, also enables data output drivers
		2    R\W  WR_EN     Data line driver control: 1=drives output lines D7-D0 0=idle
		1     R   RXF_       
		0    R\W  RD        Rd pin (inverted in CPLD): 1=Read
		LSB
		*/
		#define FTDI_DEBUG_CTRL_REG (*(vu16*)0x8000006)

	#endif /* end USE_PLATFORM_NDS */

#endif  /* End of define HARDWARE_H */
